@@ -19,9 +19,9 @@ from typing import List, Optional
 
 from requests.structures import CaseInsensitiveDict
 
-from core.crud.crud_entity import CrudEntity
-from core.metaclass.singleton import Singleton
-from core.tools.preconditions import check_argument, check_state
+from hspylib.core.crud.crud_entity import CrudEntity
+from hspylib.core.metaclass.singleton import Singleton
+from hspylib.core.tools.preconditions import check_argument, check_state
 
 
 class SqlFactory(metaclass=Singleton):
