@@ -16,7 +16,7 @@
 from enum import Enum
 from typing import Any, List
 
-from core.tools.preconditions import check_not_none
+from hspylib.core.tools.preconditions import check_not_none
 
 
 class Enumeration(Enum):
